==> org-lsst-ccs-subsystem-ocsbridge-main-2.7.0-sources.jar: org/lsst/ccs/subsystem/ocsbridge/sim/MCMCommandSender.java <==
package org.lsst.ccs.subsystem.ocsbridge.sim;

import java.io.IOException;
import java.time.Duration;
import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.lsst.ccs.bus.messages.CommandRequest;
import org.lsst.ccs.messaging.AgentMessagingLayer;
import org.lsst.ccs.messaging.ConcurrentMessagingUtils;
import org.lsst.ccs.services.AgentLockService;
import org.lsst.ccs.services.UnauthorizedLevelException;
import org.lsst.ccs.services.UnauthorizedLockException;

/**
 * A wrapper around ConcurrentMessageUtilities with support for strong typing of
 * responses, and more explicit error handling
 *
 * @author tonyj
 */
public class MCMCommandSender {

    private static final Logger LOG = Logger.getLogger(MCMCommandSender.class.getName());

    private final ConcurrentMessagingUtils cmu;
    private final String target;
    private final AgentLockService lockService;
    private final AgentMessagingLayer agentMessagingLayer;

    MCMCommandSender(String target, AgentMessagingLayer agentMessagingLayer, AgentLockService lockService) {
        this.target = target;
        this.lockService = lockService;
        this.agentMessagingLayer = agentMessagingLayer;
        cmu = new ConcurrentMessagingUtils(agentMessagingLayer);
    }

    /**
     * Send a command with no return and no timeout
     *
     * @param target The subsystem to send to
     * @param command The command
     * @param args The command arguments, if any
     * @throws ExecutionException If something goes wrong
     */
    void sendCommand(String command, Object... args) throws ExecutionException {
        sendCommand(Void.TYPE, null, command, args);
    }

    <T> T sendCommand(Class<T> returnType, String command, Object... args) throws ExecutionException {
        return sendCommand(returnType, null, command, args);
    }

    /**
     * Send a command
     *
     * @param <T> The return type
     * @param target The subsystem to send to
     * @param command The command to send
     * @param returnType The expected return type
     * @param timeout The timeout (or null to use default)
     * @param args The command arguments, if any
     * @return The result
     * @throws ExecutionException If something goes wrong
     */
    <T> T sendCommand(Class<T> returnType, Duration timeout, String command, Object... args) throws ExecutionException {
        CommandRequest request = new CommandRequest(target, command, args);
        try {
            LOG.log(Level.INFO, "Sending {0} to {1}", new Object[]{ command, target});
            long start = System.nanoTime();
            Object result = timeout == null ? cmu.sendSynchronousCommand(request) : cmu.sendSynchronousCommand(request, timeout);
            long stop = System.nanoTime();
            LOG.log(Level.INFO, "Sent {0} to {1} took {2}ns", new Object[]{ command, target, stop-start });
            return returnType.cast(result);
        } catch (Exception ex) {
            throw new ExecutionException(String.format("Error sending command %s to %s", command, target), ex);
        }
    }

    // Move to ControlledSubsystem?
    void lock(int level) throws UnauthorizedLevelException, UnauthorizedLockException, IOException {
        lockService.setLevelForAgent(target, level);
    }

    void unlock() {

    }

}

==> org-lsst-ccs-subsystem-ocsbridge-main-42.0.2-sources.jar: org/lsst/ccs/subsystem/ocsbridge/sim/MCMCommandSender.java <==
package org.lsst.ccs.subsystem.ocsbridge.sim;

import java.time.Duration;
import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.lsst.ccs.bus.messages.CommandRequest;
import org.lsst.ccs.messaging.AgentMessagingLayer;
import org.lsst.ccs.messaging.ConcurrentMessagingUtils;

/**
 * A wrapper around ConcurrentMessageUtilities with support for strong typing of
 * responses, and more explicit error handling
 *
 * @author tonyj
 */
public class MCMCommandSender {

    private static final Logger LOG = Logger.getLogger(MCMCommandSender.class.getName());

    private final ConcurrentMessagingUtils cmu;
    private final String target;

    MCMCommandSender(String target, AgentMessagingLayer agentMessagingLayer) {
        this.target = target;
        cmu = new ConcurrentMessagingUtils(agentMessagingLayer);
    }

    /**
     * Send a command with no return and no timeout
     *
     * @param target The subsystem to send to
     * @param command The command
     * @param args The command arguments, if any
     * @throws ExecutionException If something goes wrong
     */
    void sendCommand(String command, Object... args) throws ExecutionException {
        sendCommand(Void.TYPE, null, command, args);
    }

    <T> T sendCommand(Class<T> returnType, String command, Object... args) throws ExecutionException {
        return sendCommand(returnType, null, command, args);
    }

    /**
     * Send a command
     *
     * @param <T> The return type
     * @param target The subsystem to send to
     * @param command The command to send
     * @param returnType The expected return type
     * @param timeout The timeout (or null to use default)
     * @param args The command arguments, if any
     * @return The result
     * @throws ExecutionException If something goes wrong
     */
    <T> T sendCommand(Class<T> returnType, Duration timeout, String command, Object... args) throws ExecutionException {
        CommandRequest request = new CommandRequest(target, command, args);
        try {
            LOG.log(Level.INFO, "Sending {0} to {1}", new Object[]{ command, target});
            long start = System.nanoTime();
            Object result = timeout == null ? cmu.sendSynchronousCommand(request) : cmu.sendSynchronousCommand(request, timeout);
            long stop = System.nanoTime();
            LOG.log(Level.INFO, "Sent {0} to {1} took {2}ns", new Object[]{ command, target, stop-start });
            return returnType.cast(result);
        } catch (Exception ex) {
            throw new ExecutionException(String.format("Error sending command %s to %s", command, target), ex);
        }
    }
}
